@@ -41,14 +41,17 @@ class Utils:
         return model_name
 
     @staticmethod
-    def read_yaml(file: str) -> Dict:
+    def read_yaml(file: Path) -> Dict:
         yaml_file = YAML(typ="safe").load(file)
         return yaml_file
 
     @staticmethod
     def retrieve_data_set_id(client: CogniteClient) -> int:
-        data_sets_id = client.data_sets.list(limit=-1).to_pandas().query('name == "AIR"').id.iloc[0]
-        return data_sets_id
+        air_data_set = client.data_sets.list(limit=-1).to_pandas().query('name == "AIR"')
+        if not air_data_set.shape[0]:
+            raise BaseException("AIR data set does not exist.")
+        data_set_id = air_data_set.id.iloc[0]
+        return data_set_id
 
     @classmethod
     def retrieve_project_name(cls) -> str:
@@ -61,6 +64,7 @@ class Utils:
 
         if metadata is None:
             metadata = {}
+
         metadata.update(
             {
                 "model": cls.retrieve_model_name(),
@@ -108,9 +112,7 @@ class Utils:
     def retrieve_clean_model_name(cls, client: CogniteClient) -> str:
         schedule_config = cls.retrieve_schedule_config(client)
         metadata = schedule_config.get("metadata")
-        if metadata:
-            return metadata.get("frontEndName")
-        return ""
+        return metadata.get("frontEndName") if metadata else ""
 
     @classmethod
     def retrieve_model_asset_id(cls, client: CogniteClient) -> int:
@@ -130,8 +132,8 @@ class Utils:
 
     @classmethod
     def retrieve_dependency(cls, model_name: str) -> str:
-        path = cls._path_to_function_dir().parent / "resources/dependencies.yaml"
-        dependency = cls.read_yaml(str(path)).get(model_name)
+        path = cls._path_to_function_dir() / "resources/dependencies.yaml"
+        dependency = cls.read_yaml(path).get(model_name)
         return dependency if dependency else ""
 
     @classmethod
